@@ -10,7 +10,7 @@ def ensure_installed():
     """
     A method which will raise an exception if Node.js is not installed.
     """
-    utils.ensure_dependency_installed(utils.NODE_NAME)
+    utils.raise_if_dependency_missing(utils.NODE_NAME)
 
 
 def ensure_version_gte(required_version):
@@ -22,7 +22,7 @@ def ensure_version_gte(required_version):
 
     `version_required`: a tuple containing the minimum version required.
 
-    ```python
+    ```
     from django_node import node
 
     node_version_required = (0, 10, 0)
@@ -31,14 +31,14 @@ def ensure_version_gte(required_version):
     ```
     """
     ensure_installed()
-    utils.ensure_dependency_version_gte(utils.NODE_NAME, required_version)
+    utils.raise_if_dependency_version_less_than(utils.NODE_NAME, required_version)
 
 
 def run(*args):
     """
     A method which will invoke Node.js with the arguments provided and return the resulting stderr and stdout.
 
-    ```python
+    ```
     from django_node import node
 
     stderr, stdout = node.run('/path/to/some/file.js', '--some-argument')
